Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(513)

Unified Diff: services/shell/runner/host/in_process_native_runner.h

Issue 2397353002: Purge references of "Mojo Application" from comments & var names. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/shell/runner/host/in_process_native_runner.h
diff --git a/services/shell/runner/host/in_process_native_runner.h b/services/shell/runner/host/in_process_native_runner.h
index 99e40db471f1207fa1897a1845f1304a4bc70bd2..91056a3e6584267e7b7bc0f0abe9dec4a20da70c 100644
--- a/services/shell/runner/host/in_process_native_runner.h
+++ b/services/shell/runner/host/in_process_native_runner.h
@@ -13,7 +13,6 @@
#include "base/scoped_native_library.h"
#include "base/threading/simple_thread.h"
#include "services/shell/native_runner.h"
-#include "services/shell/runner/host/native_application_support.h"
namespace base {
class TaskRunner;
@@ -21,8 +20,8 @@ class TaskRunner;
namespace shell {
// An implementation of |NativeRunner| that loads/runs the given app (from the
// file system) on a separate thread (in the current process).
class InProcessNativeRunner : public NativeRunner,
public base::DelegateSimpleThread::Delegate {
public:
@@ -31,21 +30,21 @@ class InProcessNativeRunner : public NativeRunner,
// NativeRunner:
mojom::ServicePtr Start(
- const base::FilePath& app_path,
+ const base::FilePath& library_path,
const Identity& target,
bool start_sandboxed,
const base::Callback<void(base::ProcessId)>& pid_available_callback,
- const base::Closure& app_completed_callback) override;
+ const base::Closure& service_completed_callback) override;
private:
// |base::DelegateSimpleThread::Delegate| method:
void Run() override;
- base::FilePath app_path_;
+ base::FilePath library_path_;
mojom::ServiceRequest request_;
- base::Callback<bool(void)> app_completed_callback_runner_;
+ base::Callback<bool(void)> service_completed_callback_runner_;
- base::ScopedNativeLibrary app_library_;
+ base::ScopedNativeLibrary library_;
std::unique_ptr<base::DelegateSimpleThread> thread_;
DISALLOW_COPY_AND_ASSIGN(InProcessNativeRunner);
@@ -57,7 +56,8 @@ class InProcessNativeRunnerFactory : public NativeRunnerFactory {
: launch_process_runner_(launch_process_runner) {}
~InProcessNativeRunnerFactory() override {}
- std::unique_ptr<NativeRunner> Create(const base::FilePath& app_path) override;
+ std::unique_ptr<NativeRunner> Create(
+ const base::FilePath& library_path) override;
private:
base::TaskRunner* const launch_process_runner_;
« no previous file with comments | « services/shell/runner/host/child_process_host.h ('k') | services/shell/runner/host/in_process_native_runner.cc » ('j') | no next file with comments »
@@ -21,8 +20,8 @@ class TaskRunner;
namespace shell {
-// An implementation of |NativeRunner| that loads/runs the given app (from the
-// file system) on a separate thread (in the current process).
+// An implementation of |NativeRunner| that loads/runs the given service (from
+// the file system) on a separate thread (in the current process).
class InProcessNativeRunner : public NativeRunner,
public base::DelegateSimpleThread::Delegate {

Powered by Google App Engine
This is Rietveld 408576698